;;; prometheus-mode.el --- Major modes for Prometheus files -*- lexical-binding: t; -*-

;; Copyright © 2023, by Peter Hoeg

;; Author: Peter Hoeg (peter@hoeg.com)
;; Created: 2023
;; Version: 0.0.1
;; Keywords: languages
;; Homepage: https://gitlab.com/peterhoeg/prometheus-mode
;; Package-Requires: ((emacs "26.1"))
;; SPDX-License-Identifier: GPL-3.0-or-later

;; This file is not part of GNU Emacs.

;;; Commentary:
;;
;; Support for various Prometheus files in Emacs. As of right now, we only
;; support the data/metrics files generated by exporters.
;;
;; As the files could be named anything and we want to be sure that we match the
;; mode based on contents, I'm using `magic-mode-alist' rather than
;; `magic-fallback-mode-alist'.

;;; Code:

(require 'rx)

;;;###autoload
(defvar prometheus-mode-line-numbers 't "Enable line numbers by default.")

(require 'prometheus-data-mode)

;;;###autoload
(add-to-list 'magic-mode-alist `(,(rx bol "#" (optional space) (or "HELP" "TYPE") space) . prometheus-data-mode))

(provide 'prometheus-mode)

;;; prometheus-mode.el ends here
